@@ -37,7 +37,6 @@ class training_class():
            self
 
         """
-        self.patch_x = 150
         self.overlap_factor = 0.5
         self.datasets_path = ''
         self.n_epochs = 20
@@ -213,7 +212,7 @@ class training_class():
 
         """
         yaml_name = self.pth_path + '//para.yaml'
-        para = {'n_epochs': 0, 'datasets_path': 0,
+        para = {'n_epochs': 0, 'datasets_path': 0, 'overlap_factor': 0,
                 'output_dir': 0, 'pth_path': 0, 'GPU': 0, 'batch_size': 0,
                 'patch_x': 0, 'patch_y': 0, 'patch_t': 0, 'gap_y': 0, 'gap_x': 0,
                 'gap_t': 0, 'lr': 0, 'b1': 0, 'b2': 0, 'fmap': 0, 'scale_factor': 0,
@@ -237,6 +236,7 @@ class training_class():
         para["scale_factor"] = self.scale_factor
         para["select_img_num"] = self.select_img_num
         para["train_datasets_size"] = self.train_datasets_size
+        para["overlap_factor"] = self.overlap_factor
         with open(yaml_name, 'w') as f:
             yaml.dump(para, f)
 
@@ -342,6 +342,7 @@ class training_class():
             train_iteration : current train_iteration number
         """
         # Crop test file into 3D patches for inference
+        self.print_img_name = True
         name_list, noise_img, coordinate_list, test_im_name = test_preprocess_chooseOne(self, img_id=0)
         # Record the inference time
         prev_time = time.time()
